@@ -28,7 +28,6 @@
 #include <QPushButton>
 #include <KConfigGroup>
 #include <QDialogButtonBox>
-#include <KGuiItem>
 #include <QVBoxLayout>
 
 
@@ -91,8 +90,8 @@ namespace Konversation
         connect(m_mainWidget->m_upChannelBtn, &QToolButton::clicked, this, &ServerGroupDialog::moveChannelUp);
         connect(m_mainWidget->m_downChannelBtn, &QToolButton::clicked, this, &ServerGroupDialog::moveChannelDown);
 
-        KGuiItem::assign(okButton, KGuiItem(i18n("&OK"), "dialog-ok", i18n("Change network information")));
-        KGuiItem::assign(buttonBox->button(QDialogButtonBox::Cancel), KGuiItem(i18n("&Cancel"), "dialog-cancel", i18n("Discards all changes made")));
+        okButton->setToolTip(i18n("Change network information"));
+        buttonBox->button(QDialogButtonBox::Cancel)->setToolTip(i18n("Discards all changes made"));
 
         m_mainWidget->m_nameEdit->setFocus();
 
@@ -484,6 +483,7 @@ namespace Konversation
         m_mainWidget->m_portSBox->setValue(server.port());
         m_mainWidget->m_passwordEdit->setText(server.password());
         m_mainWidget->m_sslChBox->setChecked(server.SSLEnabled());
+        m_mainWidget->m_proxyChBox->setChecked(!server.bypassProxy());
     }
 
     ServerSettings ServerDialog::serverSettings()
@@ -493,6 +493,7 @@ namespace Konversation
         server.setPort(m_mainWidget->m_portSBox->value());
         server.setPassword(m_mainWidget->m_passwordEdit->text());
         server.setSSLEnabled(m_mainWidget->m_sslChBox->isChecked());
+        server.setBypassProxy(!m_mainWidget->m_proxyChBox->isChecked());
 
         return server;
     }
